pub struct DbKindPeerMetaStore(pub Arc<DnaHash>);Expand description
Database kind for DbKind::PeerMetaStore
Tuple Fields
0: Arc<DnaHash>Trait Implementations
Sourceimpl Clone for DbKindPeerMetaStore
impl Clone for DbKindPeerMetaStore
Sourcefn clone(&self) -> DbKindPeerMetaStore
fn clone(&self) -> DbKindPeerMetaStore
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DbKindT for DbKindPeerMetaStore
impl DbKindT for DbKindPeerMetaStore
fn kind(&self) -> DbKind
Sourcefn filename_inner(&self) -> PathBuf
fn filename_inner(&self) -> PathBuf
The above provided
filename method attaches the .sqlite3 extension.
Implement this to provide the front part of the database filename.Sourcefn if_corrupt_wipe(&self) -> bool
fn if_corrupt_wipe(&self) -> bool
Whether to wipe the database if it is corrupt.
Some database it’s safe to wipe them if they are corrupt because
they can be refilled from the network. Other databases cannot
be refilled and some manual intervention is required.
Sourceimpl Debug for DbKindPeerMetaStore
impl Debug for DbKindPeerMetaStore
Sourceimpl Display for DbKindPeerMetaStore
impl Display for DbKindPeerMetaStore
Sourceimpl Hash for DbKindPeerMetaStore
impl Hash for DbKindPeerMetaStore
Sourceimpl PartialEq for DbKindPeerMetaStore
impl PartialEq for DbKindPeerMetaStore
impl Eq for DbKindPeerMetaStore
impl StructuralPartialEq for DbKindPeerMetaStore