pub struct PTxnGuard(/* private fields */);Expand description
Newtype to hand out connections that can only be used for running transactions
Implementations
Sourceimpl PTxnGuard
impl PTxnGuard
Sourcepub fn transaction(&mut self) -> DatabaseResult<Transaction<'_>>
pub fn transaction(&mut self) -> DatabaseResult<Transaction<'_>>
Start a new transaction on the inner connection held by this txn guard.