pub struct Schema { /* private fields */ }Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn initialize(
&self,
conn: &mut Connection,
db_kind: Option<DbKind>,
) -> Result<()>
pub fn initialize( &self, conn: &mut Connection, db_kind: Option<DbKind>, ) -> Result<()>
Determine if any database migrations need to run, and run them if so. The decision is based on the difference between this Schema’s current_index and the user_version pragma value in the database itself. NB: The current_index is 0-based, and the user_version is 1-based.